pub struct HtmlRendererEventPub { /* private fields */ }Expand description
Publisher for HTML renderer events.
Allows publishing renderer events to subscribers through a channel.
Implementations
Sourceimpl HtmlRendererEventPub
impl HtmlRendererEventPub
Sourcepub fn new() -> (Self, Receiver<RendererEvent>)
pub fn new() -> (Self, Receiver<RendererEvent>)
Creates a new event publisher and returns the publisher along with a receiver.
Sourcepub fn publish(
&self,
event: RendererEvent,
) -> Result<(), HtmlRendererEventPubError>
pub fn publish( &self, event: RendererEvent, ) -> Result<(), HtmlRendererEventPubError>
Errors
- If the sender failed to send the event