LambdaApp

Struct LambdaApp 

pub struct LambdaApp<T, R>
where T: Send + Sync + Clone, R: LambdaResponseProcessor<T> + Send + Sync + Clone,
{ pub processor: R, pub static_asset_routes: Vec<StaticAssetRoute>, /* private fields */ }
Lambda application with configurable response processing.

The main entry point for creating a Lambda-based HyperChad application. Combines a custom LambdaResponseProcessor with optional static asset routing to handle HTTP requests in AWS Lambda environment.

Fields

processor: R

The response processor for handling requests.

static_asset_routes: Vec<StaticAssetRoute>

Static asset routes (requires assets feature).

Defines routes that serve embedded static files like CSS, JavaScript, or images. Only available when the assets feature is enabled.

Implementations

Source

impl<T, R> LambdaApp<T, R>
where T: Send + Sync + Clone, R: LambdaResponseProcessor<T> + Send + Sync + Clone,

pub const fn new(to_html: R) -> LambdaApp<T, R>

Creates a new Lambda application with the given response processor.

Examples
let processor = MyProcessor;
let app = LambdaApp::new(processor);